@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.004';
+  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.005';
 }
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
 use Moose::Role;
@@ -11,7 +11,8 @@ use namespace::autoclean;
 
 has run => (
 	is => 'ro',
-	isa => 'Str',
+	isa  => 'ArrayRef',
+	default => sub { [] },
 );
 
 has notexist_fatal => (
@@ -20,28 +21,36 @@ has notexist_fatal => (
 	default => sub { 1 },
 );
 
+
 sub call_script {
 	my ( $self, @params ) = @_;
-	if ($self->run) {
-		my @cmdparts = split(' ',$self->run);
-		# this is not good, i should also check if its a command in PATH
-		if (-f $cmdparts[0]) {
-			my $command = sprintf($self->run,@params);
-			$self->log("Executing: ".$command);
-			my $output = `$command`;
-			$self->log($output);
-			$self->log_fatal("Errorlevel ".$?." on command execute") if $?;		
-			$self->log("command executed successful");
-		} else {
-			if ($self->notexist_fatal) {
-				$self->log_fatal($cmdparts[0]." command not exist - breaking up here");
-			} else {
-				$self->log($cmdparts[0]." command not exist - ignoring this");
-			}
-		}
-	}
+
+    foreach my $run_cmd (@{$self->run}) {
+
+        if ($run_cmd) {
+            
+		my $command = sprintf($run_cmd,@params);
+		$self->log("Executing: ".$command);
+		my $output = `$command`;
+		$self->log($output);
+		$self->log_fatal("Errorlevel ".$?." on command execute") if $?;     
+		$self->log("command executed successful");
+            
+        }
+    } 
 }
 
+around mvp_multivalue_args => sub {
+    my ($original, $self) = @_;
+    
+    my @res = $self->$original();
+
+    push @res, qw( run );
+    
+    @res; 
+};
+
+
 
 1;
 
@@ -54,7 +63,7 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
